.. DaCapo documentation master file, created by
   sphinx-quickstart on Tue Aug  2 16:34:19 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: DaCapo API:

   overview
   install
   tutorial
   autoapi/index
   cli

.. include:: ../../README.md
   :parser: myst_parser.sphinx_